@@ -79,6 +79,7 @@ def fun_control_init(
     test=None,
     test_seed=1234,
     test_size=0.4,
+    tkagg=False,
     train=None,
     tolerance_x=0,
     upper=None,
@@ -240,6 +241,8 @@ def fun_control_init(
         test_size (float):
             The size of the test set. Default is 0.4, i.e.,
             60% of the data is used for training and 40% for testing.
+        tkagg (bool):
+            Whether to use matplotlib TkAgg or not. Default is False.
         tolerance_x (float):
             tolerance for new x solutions. Minimum distance of new solutions,
             generated by `suggest_new_X`, to already existing solutions.
@@ -415,6 +418,7 @@ def fun_control_init(
         "test": test,
         "test_seed": test_seed,
         "test_size": test_size,
+        "tkagg": tkagg,
         "tolerance_x": tolerance_x,
         "train": train,
         "upper": upper,
